@@ -14,43 +14,26 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
-use criterion::{criterion_group, criterion_main, Criterion};
+extern crate arrow;
 
-use arrow2::array::*;
-use arrow2::chunk::Chunk;
-use arrow2::compute::filter::{build_filter, filter, filter_chunk, Filter};
-use arrow2::datatypes::DataType;
-use arrow2::util::bench_util::{create_boolean_array, create_primitive_array, create_string_array};
+use arrow::compute::Filter;
+use arrow::util::bench_util::*;
+
+use arrow::array::*;
+use arrow::compute::{build_filter, filter};
+use arrow::datatypes::{Float32Type, UInt8Type};
+
+use criterion::{criterion_group, criterion_main, Criterion};
 
 fn bench_filter(data_array: &dyn Array, filter_array: &BooleanArray) {
     criterion::black_box(filter(data_array, filter_array).unwrap());
 }
 
-fn bench_built_filter<'a>(filter: &Filter<'a>, array: &dyn Array) {
-    criterion::black_box(filter(array));
+fn bench_built_filter<'a>(filter: &Filter<'a>, data: &impl Array) {
+    criterion::black_box(filter(&data.data()));
 }
 
 fn add_benchmark(c: &mut Criterion) {
-    // scaling benchmarks
-    (10..=20).step_by(2).for_each(|log2_size| {
-        let size = 2usize.pow(log2_size);
-
-        let filter_array = create_boolean_array(size, 0.0, 0.9);
-        let filter_array =
-            BooleanArray::from_data(DataType::Boolean, filter_array.values().clone(), None);
-
-        let arr_a = create_primitive_array::<f32>(size, 0.0);
-        c.bench_function(&format!("filter 2^{} f32", log2_size), |b| {
-            b.iter(|| bench_filter(&arr_a, &filter_array))
-        });
-
-        let arr_a = create_primitive_array::<f32>(size, 0.1);
-
-        c.bench_function(&format!("filter null 2^{} f32", log2_size), |b| {
-            b.iter(|| bench_filter(&arr_a, &filter_array))
-        });
-    });
-
     let size = 65536;
     let filter_array = create_boolean_array(size, 0.0, 0.5);
     let dense_filter_array = create_boolean_array(size, 0.0, 1.0 - 1.0 / 1024.0);
@@ -60,7 +43,7 @@ fn add_benchmark(c: &mut Criterion) {
     let dense_filter = build_filter(&dense_filter_array).unwrap();
     let sparse_filter = build_filter(&sparse_filter_array).unwrap();
 
-    let data_array = create_primitive_array::<u8>(size, 0.0);
+    let data_array = create_primitive_array::<UInt8Type>(size, 0.0);
 
     c.bench_function("filter u8", |b| {
         b.iter(|| bench_filter(&data_array, &filter_array))
@@ -82,7 +65,7 @@ fn add_benchmark(c: &mut Criterion) {
         b.iter(|| bench_built_filter(&sparse_filter, &data_array))
     });
 
-    let data_array = create_primitive_array::<u8>(size, 0.5);
+    let data_array = create_primitive_array::<UInt8Type>(size, 0.5);
     c.bench_function("filter context u8 w NULLs", |b| {
         b.iter(|| bench_built_filter(&filter, &data_array))
     });
@@ -93,22 +76,10 @@ fn add_benchmark(c: &mut Criterion) {
         b.iter(|| bench_built_filter(&sparse_filter, &data_array))
     });
 
-    let data_array = create_primitive_array::<f32>(size, 0.5);
-    let data_array_nonull = create_primitive_array::<f32>(size, 0.0);
+    let data_array = create_primitive_array::<Float32Type>(size, 0.5);
     c.bench_function("filter f32", |b| {
         b.iter(|| bench_filter(&data_array, &filter_array))
     });
-    c.bench_function("filter f32 high selectivity", |b| {
-        b.iter(|| bench_filter(&data_array, &dense_filter_array))
-    });
-
-    c.bench_function("filter f32 nonull", |b| {
-        b.iter(|| bench_filter(&data_array_nonull, &filter_array))
-    });
-    c.bench_function("filter f32 nonull high selectivity", |b| {
-        b.iter(|| bench_filter(&data_array_nonull, &dense_filter_array))
-    });
-
     c.bench_function("filter context f32", |b| {
         b.iter(|| bench_built_filter(&filter, &data_array))
     });
@@ -119,7 +90,7 @@ fn add_benchmark(c: &mut Criterion) {
         b.iter(|| bench_built_filter(&sparse_filter, &data_array))
     });
 
-    let data_array = create_string_array::<i32>(size, 4, 0.5, 42);
+    let data_array = create_string_array::<i32>(size, 0.5);
     c.bench_function("filter context string", |b| {
         b.iter(|| bench_built_filter(&filter, &data_array))
     });
@@ -129,14 +100,6 @@ fn add_benchmark(c: &mut Criterion) {
     c.bench_function("filter context string low selectivity", |b| {
         b.iter(|| bench_built_filter(&sparse_filter, &data_array))
     });
-
-    let data_array = create_primitive_array::<f32>(size, 0.0);
-
-    let columns = Chunk::try_new(vec![&data_array as &dyn Array]).unwrap();
-
-    c.bench_function("filter single chunk", |b| {
-        b.iter(|| filter_chunk(&columns, &filter_array))
-    });
 }
 
 criterion_group!(benches, add_benchmark);
