@@ -15,36 +15,35 @@
 // specific language governing permissions and limitations
 // under the License.
 
-use super::{
-    data::{into_buffers, new_buffers},
-    ArrayData, ArrayDataBuilder, OffsetSizeTrait,
-};
 use crate::{
     buffer::MutableBuffer,
     datatypes::DataType,
     error::{ArrowError, Result},
     util::bit_util,
 };
-use half::f16;
 use std::mem;
 
+use super::{
+    data::{into_buffers, new_buffers},
+    ArrayData,
+};
+use crate::array::StringOffsetSizeTrait;
+
 mod boolean;
 mod fixed_binary;
-mod fixed_size_list;
 mod list;
 mod null;
 mod primitive;
 mod structure;
-mod union;
 mod utils;
 mod variable_size;
 
-type ExtendNullBits<'a> = Box<dyn Fn(&mut _MutableArrayData, usize, usize) + 'a>;
+type ExtendNullBits<'a> = Box<Fn(&mut _MutableArrayData, usize, usize) + 'a>;
 // function that extends `[start..start+len]` to the mutable array.
-// this is dynamic because different data_types influence how buffers and children are extended.
-type Extend<'a> = Box<dyn Fn(&mut _MutableArrayData, usize, usize, usize) + 'a>;
+// this is dynamic because different data_types influence how buffers and childs are extended.
+type Extend<'a> = Box<Fn(&mut _MutableArrayData, usize, usize, usize) + 'a>;
 
-type ExtendNulls = Box<dyn Fn(&mut _MutableArrayData, usize)>;
+type ExtendNulls = Box<Fn(&mut _MutableArrayData, usize) -> ()>;
 
 /// A mutable [ArrayData] that knows how to freeze itself into an [ArrayData].
 /// This is just a data container.
@@ -64,7 +63,7 @@ struct _MutableArrayData<'a> {
 }
 
 impl<'a> _MutableArrayData<'a> {
-    fn freeze(self, dictionary: Option<ArrayData>) -> ArrayDataBuilder {
+    fn freeze(self, dictionary: Option<ArrayData>) -> ArrayData {
         let buffers = into_buffers(&self.data_type, self.buffer1, self.buffer2);
 
         let child_data = match self.data_type {
@@ -77,19 +76,19 @@ impl<'a> _MutableArrayData<'a> {
                 child_data
             }
         };
-
-        let mut array_data_builder = ArrayDataBuilder::new(self.data_type)
-            .offset(0)
-            .len(self.len)
-            .null_count(self.null_count)
-            .buffers(buffers)
-            .child_data(child_data);
-        if self.null_count > 0 {
-            array_data_builder =
-                array_data_builder.null_bit_buffer(self.null_buffer.into());
-        }
-
-        array_data_builder
+        ArrayData::new(
+            self.data_type,
+            self.len,
+            Some(self.null_count),
+            if self.null_count > 0 {
+                Some(self.null_buffer.into())
+            } else {
+                None
+            },
+            0,
+            buffers,
+            child_data,
+        )
     }
 }
 
@@ -98,7 +97,7 @@ fn build_extend_null_bits(array: &ArrayData, use_nulls: bool) -> ExtendNullBits
         let bytes = bitmap.bits.as_slice();
         Box::new(move |mutable, start, len| {
             utils::resize_for_bits(&mut mutable.null_buffer, mutable.len + len);
-            mutable.null_count += crate::util::bit_mask::set_bits(
+            mutable.null_count += utils::set_bits(
                 mutable.null_buffer.as_slice_mut(),
                 bytes,
                 mutable.len,
@@ -141,7 +140,6 @@ fn build_extend_null_bits(array: &ArrayData, use_nulls: bool) -> ExtendNullBits
 /// assert_eq!(Int32Array::from(vec![2, 3, 1, 2, 3]), new_array);
 /// ```
 pub struct MutableArrayData<'a> {
-    #[allow(dead_code)]
     arrays: Vec<&'a ArrayData>,
     // The attributes in [_MutableArrayData] cannot be in [MutableArrayData] due to
     // mutability invariants (interior mutability):
@@ -184,6 +182,8 @@ fn build_extend_dictionary(
     max: usize,
 ) -> Option<Extend> {
     use crate::datatypes::*;
+    use std::convert::TryInto;
+
     match array.data_type() {
         DataType::Dictionary(child_data_type, _) => match child_data_type.as_ref() {
             DataType::UInt8 => {
@@ -235,7 +235,6 @@ fn build_extend_dictionary(
 fn build_extend(array: &ArrayData) -> Extend {
     use crate::datatypes::*;
     match array.data_type() {
-        DataType::Decimal(_, _) => primitive::build_extend::<i128>(array),
         DataType::Null => null::build_extend(array),
         DataType::Boolean => boolean::build_extend(array),
         DataType::UInt8 => primitive::build_extend::<u8>(array),
@@ -260,31 +259,27 @@ fn build_extend(array: &ArrayData) -> Extend {
         | DataType::Interval(IntervalUnit::DayTime) => {
             primitive::build_extend::<i64>(array)
         }
-        DataType::Interval(IntervalUnit::MonthDayNano) => {
-            primitive::build_extend::<i128>(array)
-        }
         DataType::Utf8 | DataType::Binary => variable_size::build_extend::<i32>(array),
         DataType::LargeUtf8 | DataType::LargeBinary => {
             variable_size::build_extend::<i64>(array)
         }
-        DataType::Map(_, _) | DataType::List(_) => list::build_extend::<i32>(array),
+        DataType::List(_) => list::build_extend::<i32>(array),
         DataType::LargeList(_) => list::build_extend::<i64>(array),
         DataType::Dictionary(_, _) => unreachable!("should use build_extend_dictionary"),
         DataType::Struct(_) => structure::build_extend(array),
         DataType::FixedSizeBinary(_) => fixed_binary::build_extend(array),
-        DataType::Float16 => primitive::build_extend::<f16>(array),
-        DataType::FixedSizeList(_, _) => fixed_size_list::build_extend(array),
-        DataType::Union(_, mode) => match mode {
-            UnionMode::Sparse => union::build_extend_sparse(array),
-            UnionMode::Dense => union::build_extend_dense(array),
-        },
+        DataType::Float16 => unreachable!(),
+        /*
+        DataType::FixedSizeList(_, _) => {}
+        DataType::Union(_) => {}
+        */
+        _ => todo!("Take and filter operations still not supported for this datatype"),
     }
 }
 
 fn build_extend_nulls(data_type: &DataType) -> ExtendNulls {
     use crate::datatypes::*;
     Box::new(match data_type {
-        DataType::Decimal(_, _) => primitive::extend_nulls::<i128>,
         DataType::Null => null::extend_nulls,
         DataType::Boolean => boolean::extend_nulls,
         DataType::UInt8 => primitive::extend_nulls::<u8>,
@@ -305,10 +300,9 @@ fn build_extend_nulls(data_type: &DataType) -> ExtendNulls {
         | DataType::Timestamp(_, _)
         | DataType::Duration(_)
         | DataType::Interval(IntervalUnit::DayTime) => primitive::extend_nulls::<i64>,
-        DataType::Interval(IntervalUnit::MonthDayNano) => primitive::extend_nulls::<i128>,
         DataType::Utf8 | DataType::Binary => variable_size::extend_nulls::<i32>,
         DataType::LargeUtf8 | DataType::LargeBinary => variable_size::extend_nulls::<i64>,
-        DataType::Map(_, _) | DataType::List(_) => list::extend_nulls::<i32>,
+        DataType::List(_) => list::extend_nulls::<i32>,
         DataType::LargeList(_) => list::extend_nulls::<i64>,
         DataType::Dictionary(child_data_type, _) => match child_data_type.as_ref() {
             DataType::UInt8 => primitive::extend_nulls::<u8>,
@@ -323,23 +317,23 @@ fn build_extend_nulls(data_type: &DataType) -> ExtendNulls {
         },
         DataType::Struct(_) => structure::extend_nulls,
         DataType::FixedSizeBinary(_) => fixed_binary::extend_nulls,
-        DataType::Float16 => primitive::extend_nulls::<f16>,
-        DataType::FixedSizeList(_, _) => fixed_size_list::extend_nulls,
-        DataType::Union(_, mode) => match mode {
-            UnionMode::Sparse => union::extend_nulls_sparse,
-            UnionMode::Dense => union::extend_nulls_dense,
-        },
+        DataType::Float16 => unreachable!(),
+        /*
+        DataType::FixedSizeList(_, _) => {}
+        DataType::Union(_) => {}
+        */
+        _ => todo!("Take and filter operations still not supported for this datatype"),
     })
 }
 
-fn preallocate_offset_and_binary_buffer<Offset: OffsetSizeTrait>(
+fn preallocate_offset_and_binary_buffer<Offset: StringOffsetSizeTrait>(
     capacity: usize,
     binary_size: usize,
 ) -> [MutableBuffer; 2] {
     // offsets
     let mut buffer = MutableBuffer::new((1 + capacity) * mem::size_of::<Offset>());
     // safety: `unsafe` code assumes that this buffer is initialized with one element
-    if Offset::IS_LARGE {
+    if Offset::is_large() {
         buffer.push(0i64);
     } else {
         buffer.push(0i32)
@@ -386,8 +380,8 @@ impl<'a> MutableArrayData<'a> {
         Self::with_capacities(arrays, use_nulls, Capacities::Array(capacity))
     }
 
-    /// Similar to [MutableArrayData::new], but lets users define the preallocated capacities of the array.
-    /// See also [MutableArrayData::new] for more information on the arguments.
+    /// Similar to [MutableArray::new], but lets users define the preallocated capacities of the array.
+    /// See also [MutableArray::new] for more information on the arguments.
     ///
     /// # Panic
     /// This function panics if the given `capacities` don't match the data type of `arrays`. Or when
@@ -427,8 +421,7 @@ impl<'a> MutableArrayData<'a> {
         };
 
         let child_data = match &data_type {
-            DataType::Decimal(_, _)
-            | DataType::Null
+            DataType::Null
             | DataType::Boolean
             | DataType::UInt8
             | DataType::UInt16
@@ -438,7 +431,6 @@ impl<'a> MutableArrayData<'a> {
             | DataType::Int16
             | DataType::Int32
             | DataType::Int64
-            | DataType::Float16
             | DataType::Float32
             | DataType::Float64
             | DataType::Date32
@@ -453,7 +445,7 @@ impl<'a> MutableArrayData<'a> {
             | DataType::LargeBinary
             | DataType::Interval(_)
             | DataType::FixedSizeBinary(_) => vec![],
-            DataType::Map(_, _) | DataType::List(_) | DataType::LargeList(_) => {
+            DataType::List(_) | DataType::LargeList(_) => {
                 let childs = arrays
                     .iter()
                     .map(|array| &array.child_data()[0])
@@ -477,6 +469,7 @@ impl<'a> MutableArrayData<'a> {
             }
             // the dictionary type just appends keys and clones the values.
             DataType::Dictionary(_, _) => vec![],
+            DataType::Float16 => unreachable!(),
             DataType::Struct(fields) => match capacities {
                 Capacities::Struct(capacity, Some(ref child_capacities)) => {
                     array_capacity = capacity;
@@ -517,58 +510,39 @@ impl<'a> MutableArrayData<'a> {
                     })
                     .collect::<Vec<_>>(),
             },
-            DataType::FixedSizeList(_, _) => {
-                let childs = arrays
-                    .iter()
-                    .map(|array| &array.child_data()[0])
-                    .collect::<Vec<_>>();
-                vec![MutableArrayData::new(childs, use_nulls, array_capacity)]
+            _ => {
+                todo!("Take and filter operations still not supported for this datatype")
             }
-            DataType::Union(fields, _) => (0..fields.len())
-                .map(|i| {
-                    let child_arrays = arrays
-                        .iter()
-                        .map(|array| &array.child_data()[i])
-                        .collect::<Vec<_>>();
-                    MutableArrayData::new(child_arrays, use_nulls, array_capacity)
-                })
-                .collect::<Vec<_>>(),
         };
 
-        // Get the dictionary if any, and if it is a concatenation of multiple
-        let (dictionary, dict_concat) = match &data_type {
-            DataType::Dictionary(_, _) => {
-                // If more than one dictionary, concatenate dictionaries together
-                let dict_concat = !arrays
-                    .windows(2)
-                    .all(|a| a[0].child_data()[0].ptr_eq(&a[1].child_data()[0]));
-
-                match dict_concat {
-                    false => (Some(arrays[0].child_data()[0].clone()), false),
-                    true => {
-                        if let Capacities::Dictionary(_, _) = capacities {
-                            panic!("dictionary capacity not yet supported")
-                        }
-                        let dictionaries: Vec<_> =
-                            arrays.iter().map(|array| &array.child_data()[0]).collect();
-                        let lengths: Vec<_> = dictionaries
-                            .iter()
-                            .map(|dictionary| dictionary.len())
-                            .collect();
-                        let capacity = lengths.iter().sum();
-
-                        let mut mutable =
-                            MutableArrayData::new(dictionaries, false, capacity);
-
-                        for (i, len) in lengths.iter().enumerate() {
-                            mutable.extend(i, 0, *len)
-                        }
-
-                        (Some(mutable.freeze()), true)
+        let dictionary = match &data_type {
+            DataType::Dictionary(_, _) => match arrays.len() {
+                0 => unreachable!(),
+                1 => Some(arrays[0].child_data()[0].clone()),
+                _ => {
+                    if let Capacities::Dictionary(_, _) = capacities {
+                        panic!("dictionary capacity not yet supported")
                     }
+                    // Concat dictionaries together
+                    let dictionaries: Vec<_> =
+                        arrays.iter().map(|array| &array.child_data()[0]).collect();
+                    let lengths: Vec<_> = dictionaries
+                        .iter()
+                        .map(|dictionary| dictionary.len())
+                        .collect();
+                    let capacity = lengths.iter().sum();
+
+                    let mut mutable =
+                        MutableArrayData::new(dictionaries, false, capacity);
+
+                    for (i, len) in lengths.iter().enumerate() {
+                        mutable.extend(i, 0, *len)
+                    }
+
+                    Some(mutable.freeze())
                 }
-            }
-            _ => (None, false),
+            },
+            _ => None,
         };
 
         let extend_nulls = build_extend_nulls(data_type);
@@ -578,13 +552,8 @@ impl<'a> MutableArrayData<'a> {
             .map(|array| build_extend_null_bits(array, use_nulls))
             .collect();
 
-        let null_buffer = if use_nulls {
-            let null_bytes = bit_util::ceil(array_capacity, 8);
-            MutableBuffer::from_len_zeroed(null_bytes)
-        } else {
-            // create 0 capacity mutable buffer with the intention that it won't be used
-            MutableBuffer::with_capacity(0)
-        };
+        let null_bytes = bit_util::ceil(array_capacity, 8);
+        let null_buffer = MutableBuffer::from_len_zeroed(null_bytes);
 
         let extend_values = match &data_type {
             DataType::Dictionary(_, _) => {
@@ -593,13 +562,8 @@ impl<'a> MutableArrayData<'a> {
                     .iter()
                     .map(|array| {
                         let offset = next_offset;
-                        let dict_len = array.child_data()[0].len();
-
-                        if dict_concat {
-                            next_offset += dict_len;
-                        }
-
-                        build_extend_dictionary(array, offset, offset + dict_len)
+                        next_offset += array.child_data()[0].len();
+                        build_extend_dictionary(array, offset, next_offset)
                             .ok_or(ArrowError::DictionaryKeyOverflowError)
                     })
                     .collect();
@@ -628,17 +592,10 @@ impl<'a> MutableArrayData<'a> {
         }
     }
 
-    /// Extends this array with a chunk of its source arrays
-    ///
-    /// # Arguments
-    /// * `index` - the index of array that you what to copy values from
-    /// * `start` - the start index of the chunk (inclusive)
-    /// * `end` - the end index of the chunk (exclusive)
-    ///
+    /// Extends this [MutableArrayData] with elements from the bounded [ArrayData] at `start`
+    /// and for a size of `len`.
     /// # Panic
-    /// This function panics if there is an invalid index,
-    /// i.e. `index` >= the number of source arrays
-    /// or `end` > the length of the `index`th array
+    /// This function panics if the range is out of bounds, i.e. if `start + len >= array.len()`.
     pub fn extend(&mut self, index: usize, start: usize, end: usize) {
         let len = end - start;
         (self.extend_null_bits[index])(&mut self.data, start, len);
@@ -648,40 +605,13 @@ impl<'a> MutableArrayData<'a> {
 
     /// Extends this [MutableArrayData] with null elements, disregarding the bound arrays
     pub fn extend_nulls(&mut self, len: usize) {
-        // TODO: null_buffer should probably be extended here as well
-        // otherwise is_valid() could later panic
-        // add test to confirm
         self.data.null_count += len;
         (self.extend_nulls)(&mut self.data, len);
         self.data.len += len;
     }
 
-    /// Returns the current length
-    #[inline]
-    pub fn len(&self) -> usize {
-        self.data.len
-    }
-
-    /// Returns true if len is 0
-    #[inline]
-    pub fn is_empty(&self) -> bool {
-        self.data.len == 0
-    }
-
-    /// Returns the current null count
-    #[inline]
-    pub fn null_count(&self) -> usize {
-        self.data.null_count
-    }
-
     /// Creates a [ArrayData] from the pushed regions up to this point, consuming `self`.
     pub fn freeze(self) -> ArrayData {
-        unsafe { self.data.freeze(self.dictionary).build_unchecked() }
-    }
-
-    /// Creates a [ArrayDataBuilder] from the pushed regions up to this point, consuming `self`.
-    /// This is useful for extending the default behavior of MutableArrayData.
-    pub fn into_builder(self) -> ArrayDataBuilder {
         self.data.freeze(self.dictionary)
     }
 }
@@ -692,13 +622,12 @@ mod tests {
 
     use super::*;
 
-    use crate::array::DecimalArray;
     use crate::{
         array::{
             Array, ArrayData, ArrayRef, BooleanArray, DictionaryArray,
             FixedSizeBinaryArray, Int16Array, Int16Type, Int32Array, Int64Array,
-            Int64Builder, ListBuilder, MapBuilder, NullArray, PrimitiveBuilder,
-            StringArray, StringDictionaryBuilder, StructArray, UInt8Array,
+            Int64Builder, ListBuilder, NullArray, PrimitiveBuilder, StringArray,
+            StringDictionaryBuilder, StructArray, UInt8Array,
         },
         buffer::Buffer,
         datatypes::Field,
@@ -708,65 +637,6 @@ mod tests {
         error::Result,
     };
 
-    fn create_decimal_array(
-        array: &[Option<i128>],
-        precision: usize,
-        scale: usize,
-    ) -> DecimalArray {
-        array
-            .iter()
-            .collect::<DecimalArray>()
-            .with_precision_and_scale(precision, scale)
-            .unwrap()
-    }
-
-    #[test]
-    fn test_decimal() {
-        let decimal_array =
-            create_decimal_array(&[Some(1), Some(2), None, Some(3)], 10, 3);
-        let arrays = vec![decimal_array.data()];
-        let mut a = MutableArrayData::new(arrays, true, 3);
-        a.extend(0, 0, 3);
-        a.extend(0, 2, 3);
-        let result = a.freeze();
-        let array = DecimalArray::from(result);
-        let expected = create_decimal_array(&[Some(1), Some(2), None, None], 10, 3);
-        assert_eq!(array, expected);
-    }
-    #[test]
-    fn test_decimal_offset() {
-        let decimal_array =
-            create_decimal_array(&[Some(1), Some(2), None, Some(3)], 10, 3);
-        let decimal_array = decimal_array.slice(1, 3); // 2, null, 3
-        let arrays = vec![decimal_array.data()];
-        let mut a = MutableArrayData::new(arrays, true, 2);
-        a.extend(0, 0, 2); // 2, null
-        let result = a.freeze();
-        let array = DecimalArray::from(result);
-        let expected = create_decimal_array(&[Some(2), None], 10, 3);
-        assert_eq!(array, expected);
-    }
-
-    #[test]
-    fn test_decimal_null_offset_nulls() {
-        let decimal_array =
-            create_decimal_array(&[Some(1), Some(2), None, Some(3)], 10, 3);
-        let decimal_array = decimal_array.slice(1, 3); // 2, null, 3
-        let arrays = vec![decimal_array.data()];
-        let mut a = MutableArrayData::new(arrays, true, 2);
-        a.extend(0, 0, 2); // 2, null
-        a.extend_nulls(3); // 2, null, null, null, null
-        a.extend(0, 1, 3); //2, null, null, null, null, null, 3
-        let result = a.freeze();
-        let array = DecimalArray::from(result);
-        let expected = create_decimal_array(
-            &[Some(2), None, None, None, None, None, Some(3)],
-            10,
-            3,
-        );
-        assert_eq!(array, expected);
-    }
-
     /// tests extending from a primitive array w/ offset nor nulls
     #[test]
     fn test_primitive() {
@@ -1248,7 +1118,7 @@ mod tests {
         ]);
         let list_value_offsets =
             Buffer::from_slice_ref(&[0i32, 3, 5, 11, 13, 13, 15, 15, 17]);
-        let expected_list_data = ArrayData::try_new(
+        let expected_list_data = ArrayData::new(
             DataType::List(Box::new(Field::new("item", DataType::Int64, true))),
             8,
             None,
@@ -1256,8 +1126,7 @@ mod tests {
             0,
             vec![list_value_offsets],
             vec![expected_int_array.data().clone()],
-        )
-        .unwrap();
+        );
         assert_eq!(finished, expected_list_data);
 
         Ok(())
@@ -1330,7 +1199,7 @@ mod tests {
         ]);
         let list_value_offsets =
             Buffer::from_slice_ref(&[0, 3, 5, 5, 13, 15, 15, 15, 19, 19, 19, 19, 23]);
-        let expected_list_data = ArrayData::try_new(
+        let expected_list_data = ArrayData::new(
             DataType::List(Box::new(Field::new("item", DataType::Int64, true))),
             12,
             None,
@@ -1338,159 +1207,7 @@ mod tests {
             0,
             vec![list_value_offsets],
             vec![expected_int_array.data().clone()],
-        )
-        .unwrap();
-        assert_eq!(result, expected_list_data);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_map_nulls_append() -> Result<()> {
-        let mut builder = MapBuilder::<Int64Builder, Int64Builder>::new(
-            None,
-            Int64Builder::new(32),
-            Int64Builder::new(32),
         );
-        builder.keys().append_slice(&[1, 2, 3])?;
-        builder.values().append_slice(&[1, 2, 3])?;
-        builder.append(true)?;
-        builder.keys().append_slice(&[4, 5])?;
-        builder.values().append_slice(&[4, 5])?;
-        builder.append(true)?;
-        builder.append(false)?;
-        builder
-            .keys()
-            .append_slice(&[6, 7, 8, 100, 101, 9, 10, 11])?;
-        builder.values().append_slice(&[6, 7, 8])?;
-        builder.values().append_null()?;
-        builder.values().append_null()?;
-        builder.values().append_slice(&[9, 10, 11])?;
-        builder.append(true)?;
-
-        let a = builder.finish();
-        let a = a.data();
-
-        let mut builder = MapBuilder::<Int64Builder, Int64Builder>::new(
-            None,
-            Int64Builder::new(32),
-            Int64Builder::new(32),
-        );
-
-        builder.keys().append_slice(&[12, 13])?;
-        builder.values().append_slice(&[12, 13])?;
-        builder.append(true)?;
-        builder.append(false)?;
-        builder.append(true)?;
-        builder.keys().append_slice(&[100, 101, 14, 15])?;
-        builder.values().append_null()?;
-        builder.values().append_null()?;
-        builder.values().append_slice(&[14, 15])?;
-        builder.append(true)?;
-
-        let b = builder.finish();
-        let b = b.data();
-        let c = b.slice(1, 2);
-        let d = b.slice(2, 2);
-
-        let mut mutable = MutableArrayData::new(vec![a, b, &c, &d], false, 10);
-
-        mutable.extend(0, 0, a.len());
-        mutable.extend(1, 0, b.len());
-        mutable.extend(2, 0, c.len());
-        mutable.extend(3, 0, d.len());
-        let result = mutable.freeze();
-
-        let expected_key_array = Int64Array::from(vec![
-            Some(1),
-            Some(2),
-            Some(3),
-            Some(4),
-            Some(5),
-            Some(6),
-            Some(7),
-            Some(8),
-            Some(100),
-            Some(101),
-            Some(9),
-            Some(10),
-            Some(11),
-            // second array
-            Some(12),
-            Some(13),
-            Some(100),
-            Some(101),
-            Some(14),
-            Some(15),
-            // slice(1, 2) results in no values added
-            Some(100),
-            Some(101),
-            Some(14),
-            Some(15),
-        ]);
-
-        let expected_value_array = Int64Array::from(vec![
-            Some(1),
-            Some(2),
-            Some(3),
-            Some(4),
-            Some(5),
-            Some(6),
-            Some(7),
-            Some(8),
-            None,
-            None,
-            Some(9),
-            Some(10),
-            Some(11),
-            // second array
-            Some(12),
-            Some(13),
-            None,
-            None,
-            Some(14),
-            Some(15),
-            // slice(1, 2) results in no values added
-            None,
-            None,
-            Some(14),
-            Some(15),
-        ]);
-
-        let expected_entry_array = StructArray::from(vec![
-            (
-                Field::new("keys", DataType::Int64, false),
-                Arc::new(expected_key_array) as ArrayRef,
-            ),
-            (
-                Field::new("values", DataType::Int64, true),
-                Arc::new(expected_value_array) as ArrayRef,
-            ),
-        ]);
-
-        let map_offsets =
-            Buffer::from_slice_ref(&[0, 3, 5, 5, 13, 15, 15, 15, 19, 19, 19, 19, 23]);
-
-        let expected_list_data = ArrayData::try_new(
-            DataType::Map(
-                Box::new(Field::new(
-                    "entries",
-                    DataType::Struct(vec![
-                        Field::new("keys", DataType::Int64, false),
-                        Field::new("values", DataType::Int64, true),
-                    ]),
-                    false,
-                )),
-                false,
-            ),
-            12,
-            None,
-            Some(Buffer::from(&[0b11011011, 0b1110])),
-            0,
-            vec![map_offsets],
-            vec![expected_entry_array.data().clone()],
-        )
-        .unwrap();
         assert_eq!(result, expected_list_data);
 
         Ok(())
@@ -1553,7 +1270,7 @@ mod tests {
             // extend b[0..0]
         ]);
         let list_value_offsets = Buffer::from_slice_ref(&[0, 3, 5, 6, 9, 10, 13]);
-        let expected_list_data = ArrayData::try_new(
+        let expected_list_data = ArrayData::new(
             DataType::List(Box::new(Field::new("item", DataType::Utf8, true))),
             6,
             None,
@@ -1561,8 +1278,7 @@ mod tests {
             0,
             vec![list_value_offsets],
             vec![expected_string_array.data().clone()],
-        )
-        .unwrap();
+        );
         assert_eq!(result, expected_list_data);
         Ok(())
     }
